@@ -1,5 +1,14 @@
 from dataclasses import dataclass
 
+from loguru import logger
+
+logger.add("file_{time}.log", format='{time} {level} {message}', level='INFO',
+           rotation='1 MB', compression='zip')
+
+
+class ConfigurationError(Exception):
+    pass
+
 
 @dataclass(frozen=True)
 class Token:
@@ -13,7 +22,6 @@ class Token:
         return self.refresh_token
 
 
-# @dataclass(frozen=True)
 class Filter:
     dateFrom: str
     dateTo: str
